@@ -2,6 +2,7 @@ from .parse_args import parse_args
 from .git_repository import GitRepository
 from . import utils
 
+
 def handle_config(args):
     if args.list:
         print('\n'.join(utils.get_config()))
@@ -15,6 +16,10 @@ def handle_init(args):
         access_token=args.token,
         local_path=args.folder
     )
+    is_token_active = gr.check_token()
+    if not is_token_active:
+        print('Token is not valid.')
+        return
 
     # TODO: language-specific template
     gr.create_and_upload(
@@ -27,6 +32,10 @@ def handle_delete(args):
         name=args.path,
         access_token=args.token
     )
+    is_token_active = gr.check_token()
+    if not is_token_active:
+        print('Token is not valid.')
+        return
     if args.remote:
         gr.delete_remote()
     elif args.local:
@@ -40,16 +49,32 @@ def handle_rename(args):
         name=args.path,
         access_token=args.token
     )
+    is_token_active = gr.check_token()
+    if not is_token_active:
+        print('Token is not valid.')
+        return
     gr.rename(args.new_name)
 
 
+def handle_check_token(args):
+    gr = GitRepository(
+        name=args.path,
+        access_token=args.token
+    )
+    is_token_active = gr.check_token()
+    if not is_token_active:
+        print('Token is not valid.')
+        return
+
+
 def cli():
     args = parse_args()
     {
         'config': handle_config,
         'init': handle_init,
         'delete': handle_delete,
-        'rename': handle_rename
+        'rename': handle_rename,
+        'check-token': handle_check_token,
     }[args.command](args)
 
 
